MessageWidget class

Determines the message type (MediaType) of a ChatMessage and renders the matching message widget (text, image, audio or video).

Inheritance

Constructors

MessageWidget({Key? key, required ChatMessage message, required Color senderColor, required Color inActiveAudioSliderColor, required Color activeAudioSliderColor, TextStyle? messageContainerTextStyle, TextStyle? sendDateTextStyle, TextDirection textDirection = TextDirection.ltr, double textMessageWidthFraction = 0.5, double imageMessageWidthFraction = 0.45, double audioMessageWidthFraction = 0.7})
const

Properties

activeAudioSliderColor → Color
final
audioMessageWidthFraction → double
final
hashCode → int
The hash code for this object.
no setterinherited
imageMessageWidthFraction → double
final
inActiveAudioSliderColor → Color
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
message → ChatMessage
final
messageContainerTextStyle → TextStyle?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendDateTextStyle → TextStyle?
final
senderColor → Color
final
textDirection → TextDirection
final
textMessageWidthFraction → double
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
messageContent(ChatMessage message) → Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited