utils/constants library

Constants

kDefaultPadding → const double
kErrorColor → const Color
kLightColor → const Color
kPrimaryColor → const Color
contains the default colors for the package ui
kSecondaryColor → const Color

Functions

dateStringFormatter(DateTime date) String
function to formate the date
isNetworkSource(String url) bool
Returns true when url points to a remote resource (has a scheme such as http/https), and false when it is a local file path.