isNetworkSource function

bool isNetworkSource(
  1. String url
)

Returns true when url points to a remote resource (has a scheme such as http/https), and false when it is a local file path.

Implementation

bool isNetworkSource(String url) => Uri.parse(url).isAbsolute;