CapturedMedia class
Result returned by the in-app camera flow (capture + preview/caption).
Constructors
- CapturedMedia({required String path, String caption = '', required bool isVideo})
-
const
Properties
- caption → String
-
Optional caption the user typed on the preview screen.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isVideo → bool
-
Whether the captured media is a video (
true) or a photo (false).final - path → String
-
Local file path of the captured photo or video.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited