Returns true when url points to a remote resource (has a scheme such as http/https), and false when it is a local file path.
true
url
http
https
false
bool isNetworkSource(String url) => Uri.parse(url).isAbsolute;